@@ -88,6 +88,11 @@ qx.Class.define("callbackery.ui.form.Auto", {
                     control = new qx.ui.form.TextArea();
                     tm[s.key] = 'text';
                     break;
+                case 'hiddenText':
+                    control = new qx.ui.form.TextField();
+                    control.exclude();
+                    tm[s.key] = 'text';
+                    break;
 
                 case 'checkBox':
                     control = new qx.ui.form.CheckBox();
@@ -126,11 +131,14 @@ qx.Class.define("callbackery.ui.form.Auto", {
 
             if (s.set) {
                 if (s.widget == 'date') {
-                    if (s.set.value) {
-                        var dateValue = s.set.value * 1000; // incoming epoch seconds
-                        delete s.set.value;
+                    var dateValue = s.set.value;
+                    if (dateValue != null) {
+                        if (typeof dateValue == 'number') {
+                            dateValue *= 1000; // incoming epoch seconds
+                        }
                         control.setValue(new Date(dateValue));
                     }
+                    delete s.set.value;
                 }
                 if (s.set.filter){
                     s.set.filter = RegExp(s.filter);
@@ -305,6 +313,9 @@ qx.Class.define("callbackery.ui.form.Auto", {
                         break;
 
                     case 'bool':
+                        if (value === null) {
+                            value = false;
+                        }
                         model[setter](qx.lang.Type.isBoolean(value) ? value : parseInt(value) != 0);
                         break;
 
